{% extends 'cookie_alert/base.html' %}
{% block cookie_content %}
  <div id="cookie-modal-bg" class="cookie-modal-bg"></div>
  {{ block.super }}
{% endblock cookie_content %}
{% block cookie_classes %}modal-wrp{% endblock cookie_classes %}
